@@ -1,23 +1,23 @@
+import shutil
 import sys
 import time
-import shutil
-from os import path
-from io import StringIO
-from contextlib import contextmanager, nullcontext, ExitStack
 import webbrowser
+from contextlib import ExitStack, contextmanager, nullcontext
+from io import StringIO
+from os import path
 
 import tomlkit
-from tomlkit.toml_file import TOMLFile as BaseTOMLFile
+from myst_nb.render_outputs import get_default_render_priority
 from sphinx.application import Sphinx
 from sphinx.errors import SphinxError
 from sphinx.util import logging
-from recommonmark.transform import AutoStructify
+from tomlkit.toml_file import TOMLFile as BaseTOMLFile
 
 from .config import Config
 from .errors import MudkipError
+from .github import GitHubPagesUpdater
 from .jupyter import jupyter_notebook
 from .npm import NpmDriver, locate_package_json
-from .github import GitHubPagesUpdater
 from .watch import DirectoryWatcher
 
 
@@ -25,6 +25,27 @@ class TOMLFile(BaseTOMLFile):
     def exists(self):
         return path.isfile(self._path)
 
+    def extract(self, value=None):
+        if value is None:
+            return self.extract(self.read())
+
+        value = getattr(value, "value", value)
+
+        if isinstance(value, list):
+            return [self.extract(x) for x in value]
+        elif isinstance(value, dict):
+            return {self.extract(key): self.extract(val) for key, val in value.items()}
+        elif isinstance(value, tomlkit.items.Integer):
+            return int(value)
+        elif isinstance(value, tomlkit.items.Float):
+            return float(value)
+        elif isinstance(value, tomlkit.items.String):
+            return str(value)
+        elif isinstance(value, tomlkit.items.Bool):
+            return bool(value)
+
+        return value
+
 
 class Mudkip:
     def __init__(
@@ -43,11 +64,11 @@ class Mudkip:
             params = {}
 
             if pyproject.exists():
-                tool = pyproject.read().get("tool", {})
+                tool = pyproject.extract().get("tool", {})
                 params.update(tool.get("mudkip", {}), poetry=tool.get("poetry"))
 
             if mudkip.exists():
-                params.update(mudkip.read().get("mudkip", {}))
+                params.update(mudkip.extract().get("mudkip", {}))
 
             params.update(kwargs)
 
@@ -125,21 +146,10 @@ class Mudkip:
             self.config.output_dir.name,
         ]
 
-        self.sphinx.setup_extension("recommonmark")
-
-        recommonmark_config = {
-            "enable_auto_toc_tree": True,
-            "enable_math": True,
-            "enable_inline_math": True,
-            "enable_eval_rst": True,
-        }
-
-        self.sphinx.add_config_value("recommonmark_config", recommonmark_config, "env")
-        self.sphinx.add_transform(AutoStructify)
-
-        self.sphinx.setup_extension("nbsphinx")
-        conf.nbsphinx_execute = "always"
-        conf.nbsphinx_allow_errors = True
+        self.sphinx.setup_extension("myst_nb")
+        conf.jupyter_execute_notebooks = "force"
+        conf.execution_allow_errors = True
+        conf.nb_render_priority = {"xml": get_default_render_priority("dirhtml")}
 
         self.sphinx.setup_extension("sphinx.ext.autodoc")
         conf.autodoc_member_order = "bysource"
@@ -170,7 +180,8 @@ class Mudkip:
             self.sphinx.preload_builder(buildername)
             self.sphinx.builder = self.sphinx.create_builder(buildername)
             self.sphinx._init_env(False)
-            self.sphinx._init_builder()
+            self.sphinx.builder.set_environment(self.sphinx.env)
+            self.sphinx.builder.init()
             yield
         finally:
             self.sphinx.builder = original_builder
@@ -270,7 +281,7 @@ class Mudkip:
                 self.clean()
 
                 with self.sphinx_warning_is_error():
-                    with self.sphinx_config(nbsphinx_allow_errors=False):
+                    with self.sphinx_config(execution_allow_errors=False):
                         self.sphinx.build()
 
                         if not skip_broken_links:
@@ -324,7 +335,7 @@ class Mudkip:
             patterns.append("*.py")
 
         with ExitStack() as stack:
-            stack.enter_context(self.sphinx_config(nbsphinx_execute="never"))
+            stack.enter_context(self.sphinx_config(jupyter_execute_notebooks="auto"))
 
             notebook_url = None
             if notebook:
