@@ -3,7 +3,6 @@ from pathlib import Path
 
 from .preset import Preset
 
-
 AUTHOR_EXTRA = re.compile(r"<.*?>|\(.*?\)|\[.*?\]")
 SPACES = re.compile(r"\s+")
 
@@ -24,7 +23,7 @@ def join_authors(authors):
 
 class Config:
     default_source_dir = "docs"
-    default_output_dir = "docs/dist"
+    default_output_dir = "docs/_build"
 
     def __init__(
         self,
@@ -43,10 +42,15 @@ class Config:
         release=None,
         dev_server=None,
         poetry=None,
+        override=None,
     ):
         self.preset = preset if isinstance(preset, Preset) else Preset.get(preset)
         self.dev_server = dev_server
         self.poetry = {} if poetry is None else poetry
+        self.override = override or {}
+        self.override.setdefault("html_static_path", []).append(
+            str(Path(__file__).resolve().with_name("_static"))
+        )
 
         self.mkdir = []
 
@@ -86,13 +90,13 @@ class Config:
         self.sphinx_project = self.title
 
         self.sphinx_srcdir = self.source_dir
-        self.sphinx_outdir = self.output_dir
-        self.sphinx_doctreedir = self.sphinx_outdir / ".doctrees"
+        self.sphinx_outdir = self.output_dir / "dist"
+        self.sphinx_doctreedir = self.output_dir / "doctrees"
 
         self.sphinx_buildername = "xml"
 
         self.sphinx_confdir = None
-        self.sphinx_confoverrides = {}
+        self.sphinx_confoverrides = self.override
 
     def try_set_project_dir(self):
         self.project_dir = None
